# recsets

Portable datasets for recommender systems research

## Development

```bash
python -m venv .venv
source .venv/bin/activate
pip install -e .
pip install -r requirements-dev.txt
recsets --help
```
